# pyfocalboard
Python bindings for Focalboard HTTP API.

## Licence
MIT

## Example
To see library use visit [https://MichalKarol.github.io/pyfocalboard/](https://MichalKarol.github.io/pyfocalboard/)

## Author
Michał Karol <michal.p.karol@gmail.com>  
[Mastodon](https://mastodon.pl/@mkarol)  
[Github](https://github.com/MichalKarol)  